import sloc from 'sloc';
import Table from 'cli-table3';
import { readFile, readdir, stat } from 'fs/promises';
import { extname, join } from 'path';
async function readFileContentsRecursively(directoryPath, extension) {
    const filesAndDirectories = await readdir(directoryPath);
    const contents = await Promise.all(filesAndDirectories.map(async (name) => {
        const fullPath = join(directoryPath, name);
        const stats = await stat(fullPath);
        if (stats.isDirectory()) {
            return readFileContentsRecursively(fullPath, extension);
        }
        else if (stats.isFile() && extname(name) === extension) {
            return await readFile(fullPath, 'utf8');
        }
        return undefined;
    }));
    return contents.flat().filter(Boolean);
}
export const analyzeLinesOfCode = async (source) => {
    const { blSourcePath, tsTargetPath } = source;
    const blFiles = await readFileContentsRecursively(blSourcePath, '.bl');
    const tsFiles = await readFileContentsRecursively(tsTargetPath, '.ts');
    const blLines = blFiles.reduce((acc, file) => {
        const stats = sloc(file, 'ts');
        return acc + stats.source;
    }, 0);
    let tsLines = 0;
    for (const file of tsFiles) {
        const stats = sloc(file, 'ts');
        tsLines += stats.source;
    }
    let fileDiff = (tsFiles.length - blFiles.length) / tsFiles.length;
    let locDiff = (tsLines - blLines) / tsLines;
    fileDiff = '-' + (fileDiff * 100).toFixed(2) + '%';
    locDiff = '-' + (locDiff * 100).toFixed(2) + '%';
    const table = new Table({
        head: ['', 'TypeScript', 'Bitloops', '% Diff'],
    });
    table.push(['Files', tsFiles.length, blFiles.length, fileDiff], ['LoC', tsLines, blLines, locDiff]);
    console.log(table.toString());
};
