import { OpenAIApi, Configuration } from 'openai';
import { OpenAIRequestCommand } from './commands/command.js';
import { Invoker } from './invoker.js';
import { OpenAIGPT4RequestCommand } from './commands/gpt4-command.js';
export class Client {
    client;
    invoker = new Invoker();
    constructor(apiKey) {
        const configuration = new Configuration({ apiKey });
        this.client = new OpenAIApi(configuration);
    }
    makeOpenAIRequest(params, options) {
        const { key, isArray, fileName, metadata } = options;
        const command = new OpenAIRequestCommand(this.client, params, fileName ?? null, metadata);
        this.invoker.addCommand(key, command, isArray ?? false);
    }
    makeGPT4Request(params, options) {
        const { key, isArray, fileName, metadata } = options;
        const command = new OpenAIGPT4RequestCommand(this.client, params, fileName ?? null, metadata);
        this.invoker.addCommand(key, command, isArray ?? false);
    }
    async getResponses() {
        const responses = await this.invoker.executeCommands();
        return responses;
    }
    getTotalCost() {
        return this.invoker.getTotalCost();
    }
}
