import { CasingUtils } from '../../../../utils/casing.js';
const Suffixes = {
    TOKEN: 'Token',
    PORT: 'Port',
    WRITE_PORT: 'WriteRepoPort',
    READ_PORT: 'ReadRepoPort',
    SERVICE_PORT: 'ServicePort',
};
export const getNameFromToken = (str) => {
    if (!str.endsWith(Suffixes.TOKEN))
        throw new Error(str + ' is not a Token');
    let value = str;
    value = str.slice(0, -Suffixes.TOKEN.length);
    if (value.endsWith(Suffixes.PORT)) {
        return value.slice(0, -Suffixes.PORT.length);
    }
    return value;
};
export const getNameFromPort = (str) => {
    if (!str.endsWith(Suffixes.PORT))
        throw new Error(str + ' is not a Port');
    return str.slice(0, -Suffixes.PORT.length);
};
export const getPubSubHandlerNameFromIntegrationEvent = (str) => {
    const initialSuffix = 'IntegrationEvent';
    const finalSuffix = 'PubSubIntegrationEventHandler';
    if (!str.endsWith(initialSuffix))
        throw new Error(str + ' is not an IntegrationEvent');
    const stripped = str.slice(0, -initialSuffix.length);
    return stripped + finalSuffix;
};
export class FileNameToClassName {
    static service(name, type) {
        const nameWithoutPortSuffix = name.replace('.service-port.ts', '');
        const nameInCamelCase = CasingUtils.kebabCaseToPascalCase(nameWithoutPortSuffix);
        return type + nameInCamelCase + 'Service';
    }
    static repository(name, type) {
        const nameWithoutPortSuffix = name.replace('.repo-port.ts', '');
        const nameInCamelCase = CasingUtils.kebabCaseToPascalCase(nameWithoutPortSuffix);
        return type + nameInCamelCase + 'Repository';
    }
    static integrationEvent(name) {
        const nameWithoutSuffix = name.replace('.integration-event.ts', '');
        const nameInCamelCase = CasingUtils.kebabCaseToPascalCase(nameWithoutSuffix);
        return nameInCamelCase + 'IntegrationEvent';
    }
}
export class ClassNameToTargetFileName {
    static pubsubHandler(name) {
        const suffix = 'PubSubIntegrationEventHandler';
        const nameWithoutSuffix = name.replace(suffix, '');
        const nameInKebabCase = CasingUtils.pascalCaseToKebabCase(nameWithoutSuffix);
        return `${nameInKebabCase}.integration-handler.ts`;
    }
    static repository(name) {
        const suffix = 'Repository';
        const lastIndex = name.lastIndexOf(suffix);
        const nameWithoutSuffix = name.slice(0, lastIndex);
        const nameInKebabCase = CasingUtils.pascalCaseToKebabCase(nameWithoutSuffix);
        return `${nameInKebabCase}.repository.ts`;
    }
    static service(name) {
        const suffix = 'Service';
        const lastIndex = name.lastIndexOf(suffix);
        const nameWithoutSuffix = name.slice(0, lastIndex);
        const nameInKebabCase = CasingUtils.pascalCaseToKebabCase(nameWithoutSuffix);
        return `${nameInKebabCase}.service.ts`;
    }
}
