import * as fs from 'fs/promises';
import * as path from 'path';
import { getRecursivelyFileInDirectory } from './getRecursivelyFileInDirectory.js';
import { CodeSnippets } from '../commands/generate/data-sets/common/code-snippets.js';
const BL_SUFFIX = 'bl';
const getBitloopsFilesAndContents = async (boundedContextModules, sourceDirPath, suffix = BL_SUFFIX) => {
    const result = [];
    for (const [boundedContextName, modules] of Object.entries(boundedContextModules)) {
        for (const moduleName of modules) {
            const modulePath = path.join(sourceDirPath, boundedContextName, moduleName);
            const contextFilePaths = getRecursivelyFileInDirectory(modulePath, suffix);
            const moduleInput = await Promise.all(contextFilePaths.map(async (contextFilePath) => {
                const fileContents = await fs.readFile(contextFilePath, 'utf-8');
                const fileName = contextFilePath.split('/').pop();
                return {
                    boundedContext: boundedContextName,
                    module: moduleName,
                    fileId: contextFilePath,
                    fileName,
                    fileContents,
                };
            }));
            result.push(...moduleInput);
        }
    }
    return result;
};
const getTypescriptFilesAndContents = async (boundedContextModules, sourceDirPath) => {
    const result = {};
    for (const [boundedContextName, modules] of Object.entries(boundedContextModules)) {
        result[boundedContextName] = {};
        for (const moduleName of modules) {
            result[boundedContextName][moduleName] = [];
            const modulePath = path.join(sourceDirPath, boundedContextName, moduleName);
            const contextFilePaths = getRecursivelyFileInDirectory(modulePath, 'ts');
            const moduleFiles = await Promise.all(contextFilePaths.map(async (contextFilePath) => {
                const fileContent = await fs.readFile(contextFilePath, 'utf-8');
                const fileName = contextFilePath.split('/').pop();
                const fileContentWithoutLicense = CodeSnippets.removeLicenseCode(fileContent);
                return {
                    fileName,
                    fileContent: fileContentWithoutLicense,
                    filePath: contextFilePath,
                };
            }));
            result[boundedContextName][moduleName] = moduleFiles;
        }
    }
    return result;
};
export { getBitloopsFilesAndContents, getTypescriptFilesAndContents };
