import fs from 'fs';
import path from 'path';
const FILE_SUFFIX_DELIMITER = '.';
const FOLDER_DELIMITER = '/';
const ensureDirectoryExistence = (filePath) => {
    const dirname = path.dirname(filePath);
    if (fs.existsSync(dirname)) {
        return true;
    }
    ensureDirectoryExistence(dirname);
    fs.mkdirSync(dirname);
};
const writeToFile = (data, filePath) => {
    ensureDirectoryExistence(filePath);
    fs.writeFileSync(filePath, data);
};
const readFromFile = (filePath) => {
    if (!fs.existsSync(filePath)) {
        return null;
    }
    return fs.readFileSync(filePath, 'utf8');
};
const prependToFile = (data, filePath) => {
    const fileData = fs.readFileSync(filePath);
    const prependByteData = Buffer.from(data);
    const fd = fs.openSync(filePath, 'w+');
    fs.writeSync(fd, prependByteData, 0, prependByteData.length, 0);
    fs.writeSync(fd, fileData, 0, fileData.length, prependByteData.length);
    fs.closeSync(fd);
};
const getFilename = (filePath) => {
    const filenameParts = filePath.split(FILE_SUFFIX_DELIMITER);
    const fileNameWithoutSuffix = filenameParts[filenameParts.length - 2];
    const filePathNames = fileNameWithoutSuffix.split(FOLDER_DELIMITER);
    const fileName = filePathNames[filePathNames.length - 1];
    return fileName;
};
const copyFile = (source, dest) => {
    fs.copyFileSync(source, dest);
};
const clearFolder = (outputDirPath) => {
    fs.rmSync(path.normalize(`${outputDirPath}/src`), {
        recursive: true,
        force: true,
    });
};
export { clearFolder, writeToFile, prependToFile, readFromFile, ensureDirectoryExistence, getFilename, copyFile, };
