import { existsSync } from 'fs';
import { mkdir, readFile, writeFile } from 'fs/promises';
import { homedir } from 'os';
import { join } from 'path';
import * as z from 'zod';
const boundedContext = z.record;
const moduleName = z.record;
const BitloopsProjectConfigSchema = z.object({
    concretions: boundedContext(moduleName(z.record(z.union([z.literal('Mock'), z.literal('Mongo'), z.literal('Postgres')])))),
    api: z.object({
        grpc: z.object({
            package: z.string(),
            'service-name': z.string(),
            controllers: boundedContext(moduleName(z.object({
                entities: z.array(z.string()),
                handlers: z.record(z.string()),
            }))),
            'stream-events': boundedContext(moduleName(z.array(z.string()))),
        }),
    }),
});
const homeDirectory = homedir();
const configDirectory = join(homeDirectory, '.bitloops');
const configFile = join(configDirectory, '.bitloopsrc');
const bitloopsProjectConfigFileName = 'bitloops.config.json';
export class ConfigUtils {
    static async readApiKey() {
        try {
            const config = await readFile(configFile, 'utf-8');
            return JSON.parse(config).api_key ?? null;
        }
        catch (error) {
            return null;
        }
    }
    static async writeApiKey(apiKey) {
        const configDirExists = existsSync(configDirectory);
        if (!configDirExists) {
            await mkdir(configDirectory);
        }
        const config = JSON.stringify({ api_key: apiKey });
        await writeFile(configFile, config, 'utf-8');
    }
    static async readBitloopsProjectConfigFile() {
        const cwd = process.cwd();
        const filePath = join(cwd, bitloopsProjectConfigFileName);
        try {
            const config = await readFile(filePath, 'utf-8');
            const parsedConfig = JSON.parse(config);
            const validatedConfig = BitloopsProjectConfigSchema.parse(parsedConfig);
            return validatedConfig;
        }
        catch (error) {
            if (error instanceof z.ZodError) {
                console.error('Validation error:', error.message);
                console.error('Validation errors:', error.errors);
                throw error;
            }
            else {
                throw new Error(error.message ?? 'Unable to read bitloops.config.json file');
            }
        }
    }
}
